@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "FilesUpdateAdaptor.h"
+#include "base/ddlog.h"
 #include <QtCore/QMetaObject>
 #include <QtCore/QByteArray>
 #include <QtCore/QList>
@@ -10,6 +11,7 @@
 #include <QtCore/QString>
 #include <QtCore/QStringList>
 #include <QtCore/QVariant>
+#include <QDebug>
 
 /*
  * Implementation of adaptor class FilesUpdateAdaptor
@@ -19,17 +21,21 @@ FilesUpdateAdaptor::FilesUpdateAdaptor(QObject *parent)
     : QDBusAbstractAdaptor(parent)
 {
     // constructor
+    qCDebug(app) << "Creating FilesUpdateAdaptor instance";
     setAutoRelaySignals(true);
+    qCDebug(app) << "Auto relay signals enabled";
 }
 
 FilesUpdateAdaptor::~FilesUpdateAdaptor()
 {
     // destructor
+    qCDebug(app) << "Destroying FilesUpdateAdaptor instance";
 }
 
 void FilesUpdateAdaptor::OnFilesUpdate(const QStringList &list)
 {
     // handle method call local.ManualFilesUpdateProxy.OnFilesUpdate
     QMetaObject::invokeMethod(parent(), "OnFilesUpdate", Q_ARG(QStringList, list));
+    qCDebug(app) << "Received signal OnFilesUpdate with arguments size:" << list.size();
 }
 
