@@ -6,6 +6,7 @@
 #include "base/command.h"
 #include "base/utils.h"
 #include "base/consts.h"
+#include "base/ddlog.h"
 #include "controller/filewatcher.h"
 #include "controller/search_db.h"
 #include "view/jscontext.h"
@@ -21,11 +22,19 @@ helperManager::helperManager(QObject *parent)
     , timerObj(new QTimer(this))
     , jsObj(new JsContext(this))
 {
+    qCDebug(app) << "Initializing helperManager";
     timerObj->setSingleShot(true);
     timerObj->setInterval(1000);
+
+    qCDebug(app) << "Initializing web components";
     initWeb();
+
+    qCDebug(app) << "Initializing database configuration";
     initDbConfig();
+
+    qCDebug(app) << "Setting up signal connections";
     initConnect();
+    qCDebug(app) << "helperManager initialized successfully";
 }
 
 /**
@@ -33,7 +42,8 @@ helperManager::helperManager(QObject *parent)
  */
 void helperManager::initWeb()
 {
-    qDebug() << Q_FUNC_INFO;
+    qCDebug(app) << "initWeb";
+
     m_webView = new QWebEngineView;
     m_webView->setFixedSize(400, 200);
     connect(m_webView->page(), &QWebEnginePage::loadFinished, this, &helperManager::webLoadFinish);
@@ -41,7 +51,9 @@ void helperManager::initWeb()
     m_webChannel->registerObject("context", jsObj);
     m_webView->page()->setWebChannel(m_webChannel);
     const QFileInfo info(kSearchIndexPage);
+    qCDebug(app) << "Loading web page from:" << info.absoluteFilePath();
     m_webView->load(QUrl::fromLocalFile(info.absoluteFilePath()));
+    qCDebug(app) << "Web components initialized";
 }
 
 /**
@@ -49,9 +61,11 @@ void helperManager::initWeb()
  */
 void helperManager::initDbConfig()
 {
+    qCDebug(app) << "initDbConfig";
     dbObj->initDb();
     dbObj->initSearchTable();
     dbObj->initTimeTable();
+    qCDebug(app) << "Database initialized";
 }
 
 /**
@@ -59,22 +73,27 @@ void helperManager::initDbConfig()
  */
 void helperManager::getModuleInfo()
 {
+    qCDebug(app) << "getModuleInfo";
     //获取数据库中所有文件更新时间
     QMap<QString, QString> mapFile =  dbObj->selectAllFileTime();
     QMap<QString, QString> mapNow;
     QStringList  assetsPathList = Utils::getSystemManualDir();
+    qCDebug(app) << "assetsPathList:" << assetsPathList;
     foreach (auto assetsPath, assetsPathList) {
         for (const QString &type : QDir(assetsPath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
             if (type == "system" || type == "application") {
                 QString typePath = assetsPath + "/" + type;
+                qCDebug(app) << "typePath:" << typePath;
                 //监控资源文件夹
                 for (QString &module : QDir(typePath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
                     //./manual-assets/application(system)/appName
                     QString modulePath = typePath + "/" + module;
+                    qCDebug(app) << "modulePath:" << modulePath;
                     QStringList listAppNameT = QDir(modulePath).entryList(QDir::NoDotAndDotDot | QDir::Dirs);
+                    qCDebug(app) << "listAppNameT:" << listAppNameT;
 
                     if (listAppNameT.count() != 1) {
-                        qCritical() << Q_FUNC_INFO << modulePath  << "：there are more folders..:" << listAppNameT.count();
+                        qCCritical(app) << modulePath  << "：there are more folders..:" << listAppNameT.count();
                         continue;
                     }
                     //./manual-assets/application(system)/appName/appNameT
@@ -83,14 +102,17 @@ void helperManager::getModuleInfo()
                         if (0 != lang.compare("common")) {
                             //./manual-assets/application(system)/appName/appNameT/lang
                             QString langPath = appPath + "/" + lang;
+                            qCDebug(app) << "langPath:" << langPath;
                             for (QString &mdFile : QDir(langPath).entryList(QDir::Files)) {
                                 if (mdFile.endsWith("md")) {
                                     //./manual-assets/application(system)/appName/appNameT/lang/md
                                     QString strMd = langPath + "/" + mdFile;
+                                    qCDebug(app) << "strMd:" << strMd;
                                     QFileInfo fileInfo(strMd);
                                     if (fileInfo.exists()) {
                                         QString modifyTime = fileInfo.lastModified().toString("yyyy-MM-dd hh:mm:ss.zzz");
                                         mapNow.insert(strMd, modifyTime);
+                                        qCDebug(app) << "File changed:" << strMd << "modifyTime:" << modifyTime;
                                     }
                                 }
                             }
@@ -105,16 +127,19 @@ void helperManager::getModuleInfo()
         for (const QString &system : QDir(assetsPath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
             if (systemType.contains(system)) {
                 QString typePath = assetsPath + "/" + system;
+                qCDebug(app) << "typePath:" << typePath;
                 for (QString &module : QDir(typePath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
                     QString modulePath = typePath + "/" + module;
                     for (QString &lang : QDir(modulePath).entryList(QDir::NoDotAndDotDot | QDir::Dirs)) {
                         // 除了common目录其它其它都是各语言对应文档目录
                         if (0 != lang.compare("common")) {
                             QString strMd = modulePath + "/" + lang + "/index.md";
+                            qCDebug(app) << "strMd:" << strMd;
                             QFileInfo fileInfo(strMd);
                             if (fileInfo.exists()) {
                                 QString modifyTime = fileInfo.lastModified().toString("yyyy-MM-dd hh:mm:ss.zzz");
                                 mapNow.insert(strMd, modifyTime);
+                                qCDebug(app) << "File changed:" << strMd << "modifyTime:" << modifyTime;
                             }
                         }
                     }
@@ -128,6 +153,7 @@ void helperManager::getModuleInfo()
     if (fileInfo.exists()) {
         QString modifyTime = fileInfo.lastModified().toString("yyyy-MM-dd hh:mm:ss.zzz");
         mapNow.insert(kVideoConfigPath, modifyTime);
+        qCDebug(app) << "File changed:" << kVideoConfigPath << "modifyTime:" << modifyTime;
     }
 
     QStringList deleteList;
@@ -136,14 +162,19 @@ void helperManager::getModuleInfo()
     watcherObj->setFileMap(mapNow);
     //白名单对比，得到差异列表信息
     watcherObj->checkMap(mapFile, mapNow, deleteList, addList, addTime);
+    qCDebug(app) << "deleteList:" << deleteList;
+    qCDebug(app) << "addList:" << addList;
+    qCDebug(app) << "addTime:" << addTime;
     handleDb(deleteList, addList, addTime);
 }
 
 void helperManager::initConnect()
 {
+    qCDebug(app) << "initConnect";
     connect(jsObj, &JsContext::parseMsg, this, &helperManager::onRecvParseMsg);
     connect(watcherObj, &fileWatcher::filelistChange, this, &helperManager::onFilelistChange);
     connect(timerObj, &QTimer::timeout, this, &helperManager::onTimerOut);
+    qCDebug(app) << "Signal connections established";
 }
 
 /**
@@ -155,8 +186,9 @@ void helperManager::initConnect()
  */
 void helperManager::handleDb(const QStringList &deleteList, const QStringList &addList, const QStringList &addTime)
 {
-    qDebug() << Q_FUNC_INFO << deleteList.count() << " " << addList.count();
+    qCDebug(app) << deleteList.count() << " " << addList.count();
     if (!deleteList.isEmpty()) {
+        qCDebug(app) << "deleteList:" << deleteList;
         dbObj->deleteFilesTimeEntry(deleteList);
         QStringList appList;
         QStringList langList;
@@ -164,30 +196,34 @@ void helperManager::handleDb(const QStringList &deleteList, const QStringList &a
             if (path.contains("video-guide")) {
                 appList << "video-guide" << "video-guide";
                 langList << "en_US" << "zh_CN";
+                qCDebug(app) << "video-guide file changed, delete all entries";
             } else {
                 QStringList list = path.split("/");
                 if (list.count() >= 4) {
                     langList.append(list.at(list.count() - 2));
                     appList.append(list.at(list.count() - 4));
+                    qCDebug(app) << "langList:" << langList << "appList:" << appList;
                 }
+                qCDebug(app) << "deleteList:" << path;
             }
         }
 
         dbObj->deleteSearchInfo(appList, langList);
     }
 
+    qCDebug(app) << addList.count() << " " << addTime.count();
     QStringList tmpAddList = addList;
     int videoIndex = tmpAddList.indexOf(kVideoConfigPath);
     if (videoIndex >= 0) { //视频配置文件单独拿出来处理
 //        tmpAddList.removeAt(videoIndex);
         QFile file(kVideoConfigPath);
         if (!file.open(QIODevice::ReadOnly)) {
-            qDebug() << "Failed to open video config file.";
+            qCDebug(app) << "Failed to open video config file.";
         } else {
             QByteArray jsonData = file.readAll();
             QJsonDocument jsonDoc = QJsonDocument::fromJson(jsonData);
             if (jsonDoc.isNull()) {
-                qDebug() << "Failed to parse JSON of video config file.";
+                qCDebug(app) << "Failed to parse JSON of video config file.";
             } else {
                 QJsonObject jsonObj = jsonDoc.object();
 
@@ -229,13 +265,16 @@ void helperManager::handleDb(const QStringList &deleteList, const QStringList &a
 
                                     anchorIdList.append(QString("h%0").arg(i));
                                     contents.append(obj["url"].toString());
+                                    qCDebug(app) << "video name:" << obj["name[en_US]"].toString() << obj["name[zh_CN]"].toString();
                                 }
                             }
                         }
                     }
                     for(QString lang_key : anchors.keys()) {
-                        if (anchorInitialList.keys().contains(lang_key) && anchorSpellList.keys().contains(lang_key))
+                        if (anchorInitialList.keys().contains(lang_key) && anchorSpellList.keys().contains(lang_key)) {
                             dbObj->addSearchEntry("video-guide", lang_key, anchors[lang_key], anchorInitialList[lang_key], anchorSpellList[lang_key], anchorIdList, contents);
+                            qCDebug(app) << "video-guide addSearchEntry:" << anchors[lang_key] << anchorInitialList[lang_key] << anchorSpellList[lang_key] << anchorIdList << contents;
+                        }
                     }
                 }
             }
@@ -243,13 +282,15 @@ void helperManager::handleDb(const QStringList &deleteList, const QStringList &a
     }
 
     QStringList list = handlePriority(tmpAddList);
+    qCDebug(app) << "addList:" << list;
 
     if (!list.isEmpty() && !addTime.isEmpty()) {
+        qCDebug(app) << "addTime:" << addTime;
         dbObj->insertFilesTimeEntry(tmpAddList, addTime);
         //通过JS层函数来完成md转html, 然后解析html内所有文本内容
         if (jsObj && m_webView) {
             QString strChange = list.join(",");
-            qDebug() << Q_FUNC_INFO << strChange;
+            qCDebug(app) << strChange;
 
             m_webView->page()->runJavaScript(QString("parseMdList('%1')").arg(strChange));
         }
@@ -258,6 +299,7 @@ void helperManager::handleDb(const QStringList &deleteList, const QStringList &a
     deleteTList = deleteList;
     addTList = list;
     timerObj->start();
+    qCDebug(app) << "handleDb end";
 }
 
 /**
@@ -271,7 +313,7 @@ void helperManager::dbusSend(const QStringList &deleteList, const QStringList &a
     list << deleteList;
     list << addList;
 
-    qDebug() << Q_FUNC_INFO << list;
+    qCDebug(app) << list;
     if (!list.isEmpty()) {
         QDBusMessage msg =
             QDBusMessage::createMethodCall("com.deepin.Manual.FilesUpdate",
@@ -282,11 +324,12 @@ void helperManager::dbusSend(const QStringList &deleteList, const QStringList &a
         QDBusMessage response = QDBusConnection::sessionBus().call(msg);
 
         if (response.type() == QDBusMessage::ReplyMessage) {
-            qDebug() << Q_FUNC_INFO << "ReplyMessage";
+            qCDebug(app) << "ReplyMessage";
         } else if (response.type() == QDBusMessage::ErrorMessage) {
-            qDebug() << Q_FUNC_INFO << "ErrorMessage: " << QDBusConnection::sessionBus().lastError().message();
+            qCDebug(app) << "ErrorMessage: " << QDBusConnection::sessionBus().lastError().message();
         }
     }
+    qCDebug(app) << "dbusSend end";
 }
 
 /**
@@ -297,9 +340,9 @@ void helperManager::dbusSend(const QStringList &deleteList, const QStringList &a
  */
 QStringList helperManager::handlePriority(const QStringList &list)
 {
-    qDebug() << Q_FUNC_INFO << list;
+    qCDebug(app) << list;
     QStringList omitType = Utils::systemToOmit(Utils::uosEditionType());
-    qDebug() << Q_FUNC_INFO << omitType;
+    qCDebug(app) << omitType;
     QStringList moduleList;
     QStringList retList;
     //key: md路径  value:md文件是否为最高优先级别
@@ -314,60 +357,75 @@ QStringList helperManager::handlePriority(const QStringList &list)
             QString moduleLang = splitList.at(splitList.count() - 4) + splitList.at(splitList.count() - 2);
             QString mdFile = splitList.at(splitList.count() - 1);
             QStringList listTemp = mdFile.split("_");
+            qCDebug(app) << "moduleLang:" << moduleLang << "mdFile:" << mdFile << "listTemp:" << listTemp;
             // 首位如果包含在系统类型里， 则代表其为特定系统类型文件*_appName.md，否则为默认文件appName.md
             if (!systemList.contains(listTemp.at(0))) {
+                qCDebug(app) << "omitType:" << omitType << "listTemp:" << listTemp;
                 //如果之前没有对应的模块语言的md文件， 则直接添加
                 if (!moduleList.contains(moduleLang)) {
                     moduleList.append(moduleLang);
                     retList.append(mdPath);
+                    qCDebug(app) << "add moduleLang:" << moduleLang;
                 }
                 //如果之前存在对应的模块语言的md文件，则判断对应文件是否为最高优先级， 不是最高优先级，则添加。
                 else if (!map.value(moduleLang)) {
+                    qCDebug(app) << "moduleLang:" << moduleLang << "mdFile:" << mdFile << "listTemp:" << listTemp;
                     int nIndex = moduleList.indexOf(moduleLang);
                     if (nIndex != -1) {
                         moduleList.removeAt(nIndex);
                         retList.removeAt(nIndex);
+                        qCDebug(app) << "remove moduleLang:" << moduleLang;
                     }
                     moduleList.append(moduleLang);
                     map.insert(moduleLang, false);
                     retList.append(mdPath);
+                    qCDebug(app) << "add moduleLang:" << moduleLang;
                 }
             } else if (systemList.contains(listTemp.at(0)) && omitType.contains(listTemp.at(0))) {
                 int nIndex = moduleList.indexOf(moduleLang);
+                qCDebug(app) << "nIndex:" << nIndex;
                 if (nIndex != -1) {
                     moduleList.removeAt(nIndex);
                     retList.removeAt(nIndex);
+                    qCDebug(app) << "remove moduleLang:" << moduleLang;
                 }
                 moduleList.append(moduleLang);
                 map.insert(moduleLang, true);
                 retList.append(mdPath);
+                qCDebug(app) << "add moduleLang:" << moduleLang;
             }
         }
 
 //旧文案结构兼容  /usr/share/deepin-manual/manual-assets/[professional | server]/appName/lang/index.md
 #if 1
         if (splitList.count() == 9 && systemType.contains(splitList.at(5))) {
+            qCDebug(app) << "old structure";
             QString moduleLang = splitList.at(splitList.count() - 3) + splitList.at(splitList.count() - 2);
             if (!moduleList.contains(moduleLang)) {
                 moduleList.append(moduleLang);
                 map.insert(moduleLang, false);
                 retList.append(mdPath);
+                qCDebug(app) << "add moduleLang:" << moduleLang;
             }
         }
 #endif
     }
+    qCDebug(app) << "moduleList:" << moduleList << "retList:" << retList;
     return  retList;
 }
 
 void helperManager::onFilelistChange(QStringList deleteList, QStringList addList, QStringList addTime)
 {
+    qCDebug(app) << "onFilelistChange";
     handleDb(deleteList, addList, addTime);
+    qCDebug(app) << "onFilelistChange end";
 }
 
 void helperManager::webLoadFinish(bool ok)
 {
-    qDebug() << "dmanHelper load web======>" << ok;
+    qCDebug(app) << "dmanHelper load web======>" << ok;
     getModuleInfo();
+    qCDebug(app) << "dmanHelper load web end";
 }
 
 /**
@@ -377,6 +435,7 @@ void helperManager::webLoadFinish(bool ok)
  */
 void helperManager::onRecvParseMsg(const QString &msg, const QString &path)
 {
+    qCDebug(app) << "onRecvParseMsg";
     QStringList pathList = path.split("/");
     QString lang = pathList.at(pathList.count() - 2);
     QString appName = pathList.at(pathList.count() - 4);
@@ -386,9 +445,11 @@ void helperManager::onRecvParseMsg(const QString &msg, const QString &path)
     if (systemType.contains(pathList.at(pathList.count() - 4))) {
         lang = pathList.at(pathList.count() - 2);
         appName = pathList.at(pathList.count() - 3);
+        qCDebug(app) << "old structure";
     }
 #endif
 
+    qCDebug(app) << "msg:" << msg << "path:" << path << "lang:" << lang << "appName:" << appName;
     QJsonDocument document = QJsonDocument::fromJson(msg.toLocal8Bit());
     const QJsonArray array = document.array();
     QStringList anchors;
@@ -399,6 +460,7 @@ void helperManager::onRecvParseMsg(const QString &msg, const QString &path)
     bool invalid_entry = false;
     for (const QJsonValue &value : array) {
         if (!value.isArray()) {
+            qCWarning(app) << "Invalid JSON entry in MD parse result";
             invalid_entry = true;
             break;
         }
@@ -410,6 +472,7 @@ void helperManager::onRecvParseMsg(const QString &msg, const QString &path)
         QString title_us = anchor.at(1).toString();
         anchors.append(title_ch);
         if (lang == "zh_CN") {
+            qCDebug(app) << "title_ch:" << title_ch;
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
             QRegExp regExp("[1-9]");
 #else
@@ -418,6 +481,7 @@ void helperManager::onRecvParseMsg(const QString &msg, const QString &path)
             QString str = Dtk::Core::Chinese2Pinyin(title_ch).remove(regExp);
             anchorSpellList.append(str);
             if (id == "h0") {
+                qCDebug(app) << "id is h0";
                 QString anchorInitial;
                 for (int i = 0; i < title_ch.length(); i++) {
                     anchorInitial.append(Dtk::Core::Chinese2Pinyin(title_ch.at(i)).left(1));
@@ -427,7 +491,9 @@ void helperManager::onRecvParseMsg(const QString &msg, const QString &path)
                 anchorInitialList.append("");
             }
         } else if (lang == "en_US") {
+            qCDebug(app) << "title_us:" << title_us;
             if (id == "h0") {
+                qCDebug(app) << "id is h0";
                 QStringList listTitle = title_us.split(" ");
                 QString anchorInitial;
                 for (QString str : listTitle) {
@@ -436,21 +502,26 @@ void helperManager::onRecvParseMsg(const QString &msg, const QString &path)
                 anchorInitialList.append(anchorInitial);
             } else {
                 anchorInitialList.append("");
+                qCDebug(app) << "anchorInitialList:" << anchorInitialList;
             }
             anchorSpellList.append(title_us.remove(" "));
         } else {
             anchorInitialList.append("");
             anchorSpellList.append("");
+            qCDebug(app) << "anchorInitialList:" << anchorInitialList << "anchorSpellList:" << anchorSpellList;
         }
         const QString content = anchor.at(2).toString();
         contents.append(content);
     }
 
+    qCDebug(app) << "anchors:" << anchors << "anchorIdList:" << anchorIdList << "anchorInitialList:" << anchorInitialList << "anchorSpellList:" << anchorSpellList << "contents:" << contents;
     if (!invalid_entry) {
         dbObj->addSearchEntry(appName, lang, anchors, anchorInitialList, anchorSpellList, anchorIdList, contents, path);
+        qCDebug(app) << "addSearchEntry end";
     }
     //获取内容解析返回 重置定时器
     timerObj->start();
+    qCDebug(app) << "onRecvParseMsg end";
 }
 
 /**
@@ -458,7 +529,10 @@ void helperManager::onRecvParseMsg(const QString &msg, const QString &path)
  */
 void helperManager::onTimerOut()
 {
+    qCDebug(app) << "onTimerOut";
     if (!deleteTList.isEmpty() || !addTList.isEmpty()) {
         dbusSend(deleteTList, addTList);
+        qCDebug(app) << "dbusSend end";
     }
+    qCDebug(app) << "onTimerOut end";
 }
