@@ -6,39 +6,29 @@
 #include "controller/config_manager.h"
 #include "base/consts.h"
 #include "base/utils.h"
+#include "base/ddlog.h"
 
 #include <DDesktopEntry>
 
 #include <QIcon>
 #include <QDesktopServices>
+#include <QDir>
+#include <QSettings>
+#include <QBuffer>
+#include <QDBusInterface>
+#include <QDBusReply>
 
-namespace {
-    // 迭代查找图标
-    QString findIconFile(const QString &iconName, const QString &directory) {
-        QDirIterator it(directory,
-                        QStringList() << "*.svg",
-                        QDir::Files,
-                        QDirIterator::Subdirectories);
-
-        while (it.hasNext()) {
-            it.next();
-            if (it.fileInfo().baseName() == iconName) {
-                return it.fileInfo().absoluteFilePath();
-            }
-        }
-
-        return QString();
-    }
-}
 ManualProxy::ManualProxy(QObject *parent)
     : QObject(parent)
     , strIconTheme("")
 {
+    qCDebug(app) << "ManualProxy constructor called";
     AppInfo::registerMetaType();
 }
 
 ManualProxy::~ManualProxy()
 {
+    qCDebug(app) << "ManualProxy destructor called";
 }
 
 /**
@@ -48,6 +38,7 @@ ManualProxy::~ManualProxy()
  */
 QStringList ManualProxy::getSystemManualDir()
 {
+    qCDebug(app) << "Getting system manual directory";
     return Utils::getSystemManualDir();;
 }
 
@@ -58,9 +49,10 @@ QStringList ManualProxy::getSystemManualDir()
  */
 QStringList ManualProxy::getSystemManualList()
 {
+    qCDebug(app) << "Getting system manual list";
     QStringList list = Utils::getSystemManualList();
     saveAppList(list);
-    qDebug() << "======================>" << list;
+    qCDebug(app) << "System manual list:" << list;
     return list;
 }
 
@@ -71,6 +63,7 @@ QStringList ManualProxy::getSystemManualList()
  */
 void ManualProxy::setApplicationState(const QString &appName)
 {
+    qCDebug(app) << "Setting application state:" << appName;
     QString strApp;
     //部分传的是完整路径,部分直接是模块名称
     if (appName.contains("%2F")) {
@@ -80,18 +73,19 @@ void ManualProxy::setApplicationState(const QString &appName)
     } else {
         strApp = appName;
     }
-    qDebug() << "open app---->" << strApp;
+    qCInfo(app) << "Setting application state:" << strApp;
 
     QSettings *setting = ConfigManager::getInstance()->getSettings();
     setting->beginGroup(QString(kConfigAppList));
     if (setting->contains(strApp)) {
         setting->setValue(strApp, false);
-        qDebug() << setting->applicationName() << setting->fileName() << ": " << appName << " state=false";
+        qCDebug(app) << setting->applicationName() << setting->fileName() << ": " << appName << " state=false";
     } else {
         setting->setValue(strApp, false);
-        qDebug() << setting->fileName() << ": " << strApp << " not find";
+        qCDebug(app) << setting->fileName() << ": " << strApp << " not find";
     }
     setting->endGroup();
+    qCDebug(app) << "Application state updated - appName:" << appName << " state:" << setting->value(strApp).toBool();
 }
 
 /**
@@ -101,6 +95,7 @@ void ManualProxy::setApplicationState(const QString &appName)
  */
 QStringList ManualProxy::getUsedAppList()
 {
+    qCDebug(app) << "Getting used application list";
     QSettings *setting = ConfigManager::getInstance()->getSettings();
     setting->beginGroup(QString(kConfigAppList));
     QStringList list = setting->allKeys();
@@ -108,12 +103,14 @@ QStringList ManualProxy::getUsedAppList()
     for (int i = 0; i < list.size(); ++i) {
         if (!setting->value(list.at(i)).toBool()) {
             appList.append(list.at(i));
+            qCDebug(app) << "Found used application:" << list.at(i);
         } else {
+            qCDebug(app) << "Skipping unused application:" << list.at(i);
             continue;
         }
     }
     setting->endGroup();
-    qDebug() << "The application of already used： " << appList;
+    qCDebug(app) << "Used application list:" << appList;
     return appList;
 }
 
@@ -125,12 +122,14 @@ QStringList ManualProxy::getUsedAppList()
 bool ManualProxy::hasSelperSupport()
 {
     bool b = Utils::hasSelperSupport();
+    qCDebug(app) << "Checking Selper support status:" << b;
     return b;
 }
 
 bool ManualProxy::hasAppStore()
 {
     bool b = Utils::hasAppStore();
+    qCDebug(app) << "Checking App Store availability:" << b;
     return b;
 }
 
@@ -140,6 +139,7 @@ bool ManualProxy::hasAppStore()
  */
 void ManualProxy::finishChannel()
 {
+    qCDebug(app) << "Channel initialization completed";
     emit channelInit();
 }
 
@@ -149,28 +149,32 @@ void ManualProxy::finishChannel()
  */
 void ManualProxy::supportClick()
 {
+    qCDebug(app) << "Support button clicked";
     emit supportBeClick();
 }
 
 void ManualProxy::appStoreClick()
 {
+    qCDebug(app) << "App Store button clicked";
     emit appStoreBeClick();
 }
 
 bool ManualProxy::bIsLongSon()
 {
+    qCDebug(app) << "Checking system type";
     return Utils::judgeLoongson();
 }
 
 void ManualProxy::showUpdateLabel()
 {
+    qCDebug(app) << "Showing update label";
     emit updateLabel();
 }
 
 //根据app名称找到对应md文件
 QString ManualProxy::appToPath(const QString &appName)
 {
-    // qDebug() << __FUNCTION__ << "========>" << appName;
+    qCDebug(app) << "Converting app name to path:" << appName;
     QStringList omitType = Utils::systemToOmit(Utils::uosEditionType());
     QStringList mdList;
     QStringList  assetsPathList = Utils::getSystemManualDir();
@@ -178,8 +182,10 @@ QString ManualProxy::appToPath(const QString &appName)
         QString appPath;
         if (appName == "dde" || appName == kLearnBasicOperations || appName == kCommonApplicationLibraries || appName == "video-guide") {
             appPath = assetPath + "/system/" + appName;
+            qCDebug(app) << "dde system appPath:" << appPath;
         } else {
             appPath = assetPath + "/application/" + appName;
+            qCDebug(app) << "other appPath:" << appPath;
         }
 
         if (QDir(appPath).exists()) {
@@ -187,22 +193,27 @@ QString ManualProxy::appToPath(const QString &appName)
             QString appNameT;
             if (list.count() == 1) {
                 appNameT = list.at(0);
+                qCDebug(app) << "Single directory found:" << appNameT;
             } else if (list.count() > 1) {
-                qWarning() << Q_FUNC_INFO << assetPath << "dir greater than one:" << list;
+                qCDebug(app) << assetPath << "dir greater than one:" << list;
                 appNameT = list.at(1);
             } else {
                 appNameT = "error";
-                qWarning() << Q_FUNC_INFO << " no dir";
+                qCDebug(app) << " no dir";
             }
             appPath.append("/").append(appNameT).append("/");
             appPath = getAppLocalDir(appPath);
+            qCDebug(app) << "appPath:" << appPath;
 
             if (omitType.length() > 1) {
                 mdList.append(appPath + "/" + QString("%1_%2.md").arg(omitType.at(0)).arg(appNameT));
                 mdList.append(appPath + "/" + QString("%1_%2.md").arg(omitType.at(1)).arg(appNameT));
+                qCDebug(app) << "omitType:" << omitType.at(0) << omitType.at(1);
             } else {
+                qCDebug(app) << "else omitType:";
                 if (omitType.size() > 0) {
                     mdList.append(appPath + "/" + QString("%1_%2.md").arg(omitType.at(0)).arg(appNameT));
+                    qCDebug(app) << "omitType:" << omitType.at(0);
                 }
             }
             //根据文档命名规则不带前缀文档为所有文档的兜底文档
@@ -210,30 +221,40 @@ QString ManualProxy::appToPath(const QString &appName)
         }
 
         QString oldMdPath = assetPath;
+        qCDebug(app) << "oldMdPath:" << oldMdPath;
 
 #if (DTK_VERSION > DTK_VERSION_CHECK(5, 4, 12, 0))
         if (Dtk::Core::DSysInfo::UosServer == Dtk::Core::DSysInfo::uosType()) {
             oldMdPath += "/server";
+            qCDebug(app) << "server oldMdPath:" << oldMdPath;
         } else if (Dtk::Core::DSysInfo::UosHome == Utils::uosEditionType()) {
             oldMdPath += "/personal";
+            qCDebug(app) << "personal oldMdPath:" << oldMdPath;
         } else if (Dtk::Core::DSysInfo::UosEducation == Utils::uosEditionType()) {
             oldMdPath += "/education";
+            qCDebug(app) << "education oldMdPath:" << oldMdPath;
         } else if (Dtk::Core::DSysInfo::UosCommunity == Utils::uosEditionType()) {
             oldMdPath += "/community";
+            qCDebug(app) << "community oldMdPath:" << oldMdPath;    
         } else {
             oldMdPath += "/professional";
+            qCDebug(app) << "professional oldMdPath:" << oldMdPath;
         }
 #else
         Dtk::Core::DSysInfo::DeepinType nType = Dtk::Core::DSysInfo::deepinType();
         if (Dtk::Core::DSysInfo::DeepinServer == nType) {
             oldMdPath += "/server";
+            qCDebug(app) << "server oldMdPath:" << oldMdPath;
         } else if (Dtk::Core::DSysInfo::DeepinPersonal == nType) {
             oldMdPath += "/personal";
+            qCDebug(app) << "personal oldMdPath:" << oldMdPath;
         } else {
             if (Dtk::Core::DSysInfo::isCommunityEdition()) {
                 oldMdPath += "/community";
+                qCDebug(app) << "community oldMdPath:" << oldMdPath;
             } else {
                 oldMdPath += "/professional";
+                qCDebug(app) << "professional oldMdPath:" << oldMdPath;
             }
         }
 
@@ -242,19 +263,21 @@ QString ManualProxy::appToPath(const QString &appName)
         oldMdPath = getAppLocalDir(oldMdPath);
         mdList.append(oldMdPath.append("/index.md"));
     }
-    // qInfo() << "appToPath" << "find markdown file list" << mdList;
+
     QString ret;
     for (auto md : mdList) {
         if (QFile(md).exists()) {
+            qCDebug(app) << "Found manual file:" << md;
             ret = md;
         }
     }
     if (ret.isEmpty()) {
-        qWarning() << Q_FUNC_INFO << " no exist file:" << appName;
+        qCWarning(app) << " no exist file:" << appName;
         // TODO(wurongjie) 在之前的代码中返回了error,暂不知作用
         return "error";
     }
-    // qInfo() << "========>" << ret;
+
+    qCDebug(app) << "Found manual file:" << ret;
     return ret;
 }
 
@@ -268,7 +291,7 @@ QString ManualProxy::translateTitle(const QString &titleUS)
 //根据应用desktop文件解析图标名称并获取图标路径
 QString ManualProxy::getAppIconPath(const QString &desktopname)
 {
-    // qDebug() << "getAppIconPath: desktopname:" << desktopname;
+    qCDebug(app) << "Getting icon path for:" << desktopname;
     //首次获取默认图标主题，如果获取失败默认bloom
     if (strIconTheme.isEmpty()) {
         QFile file("/usr/share/glib-2.0/schemas/com.deepin.dde.appearance.gschema.xml");
@@ -276,73 +299,97 @@ QString ManualProxy::getAppIconPath(const QString &desktopname)
             QString strContent(file.readAll());
             strContent = Utils::regexp_label(strContent, "(icon-theme\">\n)(.*)?(['</default>])");
             strIconTheme = Utils::regexp_label(strContent, "(?<=<default>')(.*)?(?='</default>)");
+            qCDebug(app) << "Extracted icon theme:" << strIconTheme;
         }
+        
+        // 如果从文件读取失败，尝试从DBus接口获取
+        if (strIconTheme.isEmpty()) {
+            QDBusInterface interface("org.deepin.dde.Appearance1", 
+                                    "/org/deepin/dde/Appearance1", 
+                                    "org.deepin.dde.Appearance1", 
+                                    QDBusConnection::sessionBus());
+            
+            if (interface.isValid()) {
+                QVariant reply = interface.property("GlobalTheme");
+                if (reply.isValid() && !reply.isNull()) {
+                    strIconTheme = reply.toString();
+                    qCDebug(app) << "Got icon theme from DBus:" << strIconTheme;
+                } else {
+                    qCWarning(app) << "Failed to get GlobalTheme from DBus: invalid reply";
+                }
+            } else {
+                qCWarning(app) << "Failed to connect to Appearance DBus interface";
+            }
+        }
+        
+        // 如果文件和DBus都失败，使用默认主题
         if (strIconTheme.isEmpty()) {
             strIconTheme = "bloom";
+            qCDebug(app) << "Using default icon theme:" << strIconTheme;
         }
     }
 
     QString filepath = Utils::getDesktopFilePath(desktopname);
+    qCDebug(app) << "Desktop file path:" << filepath;
+
     QFile file(filepath);
     QString strIcon = desktopname;
+    
     if (file.exists()) {
+        qCDebug(app) << "Desktop file exists, reading icon name...";
         Dtk::Core::DDesktopEntry entry(filepath);
         strIcon = entry.stringValue("Icon");
-        // qDebug() << strIcon;
+        qCDebug(app) << "Found icon name:" << strIcon;
     } else {
-        qDebug() << QString("filepath:%1 not exit.. desktopname:%2").arg(filepath).arg(desktopname);
+        qCWarning(app) << QString("filepath:%1 not exist.. desktopname:%2").arg(filepath).arg(desktopname);
     }
 
-    QString strIconPath;
+    qCDebug(app) << "Icon name:" << strIcon;
+
     if (QIcon::hasThemeIcon(strIcon)) {
         QIcon icon = QIcon::fromTheme(strIcon);
-        QStringList themePaths = icon.themeSearchPaths();
-        QString iconPath;
-
-        // 遍历主题路径，查找图标文件
-        for (const QString &themePath : themePaths) {
-            QStringList iconSizes = {"96", "64", "48", "36"};
-            for (const QString &size : iconSizes) {
-                QString path = QString("%1/%2/apps/%3/%4.svg").arg(themePath).arg(strIconTheme).arg(size).arg(strIcon);
-                if (QFile::exists(path)) {
-                    iconPath = path;
-                    break;
-                }
-            }
-
-            if (!iconPath.isEmpty()) {
-                break;
+        if (!icon.isNull()) {
+            // 强制目标尺寸为 96x96， 与前端的展示尺寸一致，避免转换成base64的时候超大无法正常显示
+            QSize targetSize(96, 96);
+            QPixmap pixmap = icon.pixmap(targetSize);
+            if (!pixmap.isNull()) {
+                QByteArray byteArray;
+                QBuffer buffer(&byteArray);
+                buffer.open(QIODevice::WriteOnly);
+                pixmap.save(&buffer, "PNG");
+                buffer.close(); 
+                
+                // 转换为base64
+                QString base64 = byteArray.toBase64();
+                QString dataUrl = QString("data:image/png;base64,%1").arg(base64);
+                qCDebug(app) << "Generated data URL:" << dataUrl;
+                return dataUrl;
+            } else {
+                qCWarning(app) << "Failed to get pixmap for" << strIcon;
             }
+        } else {
+            qCWarning(app) << "Icon is null for:" << strIcon;
         }
-
-        // 上面主题查找的方式没有的时候在图标路径遍历查找一下
-        if (iconPath.isEmpty())
-        {
-            for (const QString &themePath : themePaths) {
-
-                QString findPath = findIconFile(strIcon, themePath);
-                if (QFile::exists(findPath)) {
-                    iconPath = findPath;
-                    break;
-                }
-            }
-        }
-
-        if (!iconPath.isEmpty()) {
-            strIconPath = iconPath;
-        }
+    } else {
+        qCWarning(app) << "No theme icon found for:" << strIcon;
     }
-    return strIconPath;
+
+    qCWarning(app) << "Failed to get icon for:" << strIcon;
+    return "";
 }
 
 QString ManualProxy::getLocalAppName(const QString &desktopname)
 {
+    qCDebug(app) << "Getting local app name for:" << desktopname;
     QString strdisplayname = desktopname;
     if (0 == desktopname.compare(kLearnBasicOperations, Qt::CaseInsensitive)) {
+        qCDebug(app) << "Learn Basic Operations";
         strdisplayname = tr("Learn Basic Operations");
     } else if (0 == desktopname.compare(kCommonApplicationLibraries, Qt::CaseInsensitive)) {
+        qCDebug(app) << "Common Application Libraries";
         strdisplayname = tr("Common Application Libraries");
     } else if (0 == desktopname.compare("dde", Qt::CaseInsensitive)) {
+        qCDebug(app) << "Desktop Environment";
         strdisplayname = tr("Desktop Environment");
     } else {
         QStringList pathList = Utils::getEnvsourcePath();
@@ -353,39 +400,50 @@ QString ManualProxy::getLocalAppName(const QString &desktopname)
                 Dtk::Core::DDesktopEntry entry(filepath);
                 strdisplayname = entry.genericName();
                 strdisplayname = strdisplayname.isEmpty() ? entry.ddeDisplayName() : strdisplayname;
+                qCDebug(app) << "Found local app name:" << strdisplayname;
                 return strdisplayname;
             }
         }
     }
+    qCDebug(app) << "Return local app name:" << strdisplayname;
     return strdisplayname;
 }
 
 QVariant ManualProxy::getVideoGuideInfo()
 {
+    // 暂时先将视频指南进行屏蔽
+    return QVariantList();
+
+    qCDebug(app) << "Getting video guide info";
     // 社区版不出现视频指南，返回空进行屏蔽
     if (Utils::uosEditionType() == Dtk::Core::DSysInfo::UosEdition::UosCommunity)
         return QVariantList();
 
+    qCDebug(app) << "Loading video guide info from:" << kVideoConfigPath;
     QFile file(kVideoConfigPath);
     if (!file.open(QIODevice::ReadOnly)) {
-        qDebug() << "Failed to open file";
+        qCWarning(app) << "Failed to open file";
         return QVariantList();
     }
 
     QString locale = QLocale().name();
     //藏语维语使用简体中文
     if (locale == "ug_CN" || locale == "bo_CN") {
+        qCDebug(app) << "Using simplified Chinese for locale:" << locale;
         locale = "zh_CN";
     } else if (locale == "en_US" || locale == "en_GB") {
+        qCDebug(app) << "Using English for locale:" << locale;
         locale = "en_US";
     }
 
     QByteArray jsonData = file.readAll();
+    qCDebug(app) << "Parsing video guide JSON data...";
     QJsonDocument jsonDoc = QJsonDocument::fromJson(jsonData);
     if (jsonDoc.isNull()) {
-        qDebug() << "Failed to parse JSON";
+        qCWarning(app) << "Failed to parse JSON";
         return QVariantList();
     }
+    qCDebug(app) << "Successfully parsed JSON data";
 
 //    locale = "en_US"; //test
     QJsonObject jsonObj = jsonDoc.object();
@@ -394,13 +452,16 @@ QVariant ManualProxy::getVideoGuideInfo()
         QJsonValue jsValue = jsonObj.value(key);
 
         if (jsValue.isString() && key == "url") {
+            qCDebug(app) << "Found video URL:" << jsValue.toString();
             videoUrl = jsValue.toString();
         } else if (jsValue.isArray() && key == "videos") {
+            qCDebug(app) << "Found video list:" << jsValue.toArray().count();
             QJsonArray jsArray = jsValue.toArray();
             QJsonArray resultArray;
 
             for (int i = 0; i < jsArray.count(); i++) {
                 if (jsArray[i].isObject()) {
+                    qCDebug(app) << "Is video object!";
                     QJsonObject obj = jsArray[i].toObject();
                     QJsonObject tmpObj {
                         {"cover", QString(DMAN_MANUAL_DIR"/system/video-guide/videos/" + obj["cover"].toString())},
@@ -408,12 +469,16 @@ QVariant ManualProxy::getVideoGuideInfo()
                     };
 
                     if (locale == "zh_CN") {
+                        qCDebug(app) << "Using zh_CN for locale";
                         tmpObj.insert("name", obj["name[zh_CN]"]);
                     } else if(locale == "zh_HK") {
+                        qCDebug(app) << "Using zh_HK for locale";
                         tmpObj.insert("name", obj["name[zh_HK]"]);
                     } else if(locale == "zh_TW") {
+                        qCDebug(app) << "Using zh_TW for locale";
                         tmpObj.insert("name", obj["name[zh_TW]"]);
                     } else {
+                        qCDebug(app) << "Using en_US for locale";
                         tmpObj.insert("name", obj["name[en_US]"]);
                     }
 
@@ -421,18 +486,23 @@ QVariant ManualProxy::getVideoGuideInfo()
                 }
             }
 
+            qCDebug(app) << "Final video list:" << resultArray.count();
             return resultArray.toVariantList();
         }
     }
 
+    qCWarning(app) << "Failed to find video guide info";
     return QVariantList();
 }
 
 void ManualProxy::openVideo(QString url)
 {
+    qCInfo(app) << "Opening video URL:" << url;
     if(url.isEmpty()) {
+        qCDebug(app) << "No video URL found!";
         url = videoUrl;
     }
+    qCDebug(app) << "Opening video URL:" << url;
     QDesktopServices::openUrl(url);
 }
 
@@ -444,41 +514,49 @@ void ManualProxy::openVideo(QString url)
 void ManualProxy::saveAppList(const QStringList &list)
 {
     Q_UNUSED(list)
+    qCDebug(app) << "Saving app list to config file...";
     QSettings *setting = ConfigManager::getInstance()->getSettings();
     //获取配置文件中应用列表
     setting->beginGroup(QString(kConfigAppList));
     for (int i = 0; i < list.size(); ++i) {
         if (setting->contains(list.at(i))) {
+            qCDebug(app) << "App already exists:" << list.at(i);
             continue;
         } else {
             //应用不存在则保存
             setting->setValue(list.at(i), true);
+            qCDebug(app) << "App saved:" << list.at(i);
         }
     }
     QStringList l = setting->allKeys();
     setting->endGroup();
-    qDebug() << "app config  allKeys count : " << l.size();
+    qCDebug(app) << "app config  allKeys count : " << l.size();
 }
 
 QString ManualProxy::getAppLocalDir(const QString &appPath)
 {
+    qCDebug(app) << "Getting app local dir for:" << appPath;
     //appPath like /usr/share/deepin-manual/manual-assets/application/deepin-boot-maker/boot-maker/
     QString appdir(appPath);
     QString strlocal(QLocale::system().name());
     QString AppLocalDir = QString(appPath).append(strlocal);
     QDir dir(AppLocalDir);
     //如果不存在该种语言的文档路径，藏语、维语使用简体中文，其它使用英文
-    // qInfo() << __FUNCTION__ << dir.absolutePath() << strlocal;
+
     if (!dir.exists()) {
+        qCDebug(app) << "App local dir not exists:" << AppLocalDir;
         //藏语维语使用简体中文
         if (0 == strlocal.compare("ug_CN") || 0 == strlocal.compare("bo_CN")
                 || 0 == strlocal.compare("zh_HK") || 0 == strlocal.compare("zh_TW")) {
+            qCDebug(app) << "Using zh_CN for locale:" << strlocal;
             AppLocalDir = QString(appPath).append("zh_CN");
         } else {
+            qCDebug(app) << "Using en_US for locale:" << strlocal;
             AppLocalDir = QString(appPath).append("en_US");
         }
     }
-    // qInfo() << __FUNCTION__ << "AppLocalDir:" << AppLocalDir;
+
+    qCDebug(app) << "Final app local dir:" << AppLocalDir;
     return AppLocalDir;
 }
 
