@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "view/search_proxy.h"
+#include "base/ddlog.h"
 
 #include <DLog>
 #include <QTimer>
@@ -10,10 +11,12 @@
 SearchProxy::SearchProxy(QObject *parent)
     : QObject(parent)
 {
+    qCDebug(app) << "SearchProxy constructor called";
 }
 
 SearchProxy::~SearchProxy()
 {
+    qCDebug(app) << "SearchProxy destructor called";
 }
 
 /**
@@ -23,7 +26,7 @@ SearchProxy::~SearchProxy()
  */
 void SearchProxy::getKeyword(const QString &keyword)
 {
-    qDebug() << "-->" << keyword;
+    qCDebug(app) << "Received search keyword:" << keyword;
     emit setKeyword(keyword);
 }
 
@@ -34,12 +37,14 @@ void SearchProxy::getKeyword(const QString &keyword)
  */
 void SearchProxy::updateSearch(const QString &keyword)
 {
-    qDebug() << Q_FUNC_INFO;
+    qCDebug(app) << "Updating search for keyword:" << keyword;
     //WebWindow::onSetKeyword 设置搜索框值
     emit setKeyword(keyword);
 
     //延时查找数据库： 立即查找会出现无法查到刚插入数据的情况
+    qCDebug(app) << "Scheduling search update in 1 second";
     QTimer::singleShot(1000, this, [ = ]() {
+        qCDebug(app) << "Executing delayed search update";
         //查询结果并显示 WebWindow::onTitleBarEntered
         emit updateSearchResult();
     });
