@@ -4,6 +4,7 @@
 
 #include "search_completion_delegate.h"
 #include "base/utils.h"
+#include "base/ddlog.h"
 
 #include <DStyleHelper>
 #include <DPaletteHelper>
@@ -13,6 +14,7 @@ SearchCompletionDelegate::SearchCompletionDelegate(QAbstractItemView *parent)
     : DStyledItemDelegate(parent)
     , m_parentView(parent)
 {
+    qCDebug(app) << "SearchCompletionDelegate constructor called";
 }
 
 //用于去除选中项的边框
@@ -20,12 +22,14 @@ void SearchCompletionDelegate::paint(QPainter *painter, const QStyleOptionViewIt
                                      const QModelIndex &index) const
 {
     if (index.isValid()) {
+        qCDebug(app) << "Painting completion item at row:" << index.row();
         painter->save();
         painter->setRenderHint(QPainter::Antialiasing, true);
 
         QVariant varErrorItem = index.data(Qt::DisplayRole);
         //20210629 codereview
         if (!varErrorItem.isValid()) {
+            qCWarning(app) << "Invalid item data at index:" << index;
             return;
         }
 
@@ -33,6 +37,8 @@ void SearchCompletionDelegate::paint(QPainter *painter, const QStyleOptionViewIt
 
         QString strSearchKeyword = itemModel.strSearchKeyword;
         QString strSearchAppDisplayName = itemModel.strSearchAppDisplayName;
+        qCDebug(app) << "Item data - keyword:" << strSearchKeyword
+                    << "app:" << strSearchAppDisplayName;
 
         QStyleOptionViewItem viewOption(option); //用来在视图中画一个item
 
@@ -47,7 +53,10 @@ void SearchCompletionDelegate::paint(QPainter *painter, const QStyleOptionViewIt
         painter->setFont(nameFont);
 
         QString searchText = QString("%1(%2)").arg(strSearchKeyword, strSearchAppDisplayName);
+        qCDebug(app) << "Formatted search text:" << searchText;
+
         if (option.state & QStyle::State_Selected) {
+            qCDebug(app) << "Painting selected item";
             QPainterPath path;
             QRect rect;
             rect.setX(option.rect.x());
@@ -64,7 +73,11 @@ void SearchCompletionDelegate::paint(QPainter *painter, const QStyleOptionViewIt
             QRect searchTextRect = QRect(rect.left() + 32, rect.top() + 7, rect.width() - 64, rect.height() - 14);
             QFontMetrics fontMetric(nameFont);
             const QString elidedSearchText = fontMetric.elidedText(searchText, Qt::ElideRight, rect.width() - 64);
+            qCDebug(app) << "Original text:" << searchText
+                        << "Elided text:" << elidedSearchText
+                        << "Available width:" << rect.width() - 64;
             painter->drawText(searchTextRect, Qt::AlignLeft | Qt::AlignVCenter, elidedSearchText);
+            qCDebug(app) << "Text drawn in selected state";
         } else {
             QPainterPath path;
             QRect rect;
@@ -83,7 +96,11 @@ void SearchCompletionDelegate::paint(QPainter *painter, const QStyleOptionViewIt
             QRect searchTextRect = QRect(rect.left() + 32, rect.top() + 6, rect.width() - 64, rect.height() - 13);
             QFontMetrics fontMetric(nameFont);
             const QString elidedSearchText = fontMetric.elidedText(searchText, Qt::ElideRight, rect.width() - 64);
+            qCDebug(app) << "Original text:" << searchText
+                        << "Elided text:" << elidedSearchText
+                        << "Available width:" << rect.width() - 64;
             painter->drawText(searchTextRect, Qt::AlignLeft | Qt::AlignVCenter, elidedSearchText);
+            qCDebug(app) << "Text drawn in normal state";
         }
 
         painter->restore();
@@ -95,9 +112,12 @@ void SearchCompletionDelegate::paint(QPainter *painter, const QStyleOptionViewIt
 QSize SearchCompletionDelegate::sizeHint(const QStyleOptionViewItem &option,
                                          const QModelIndex &index) const
 {
+    qCDebug(app) << "SearchCompletionDelegate::sizeHint() called for index:" << index;
     if (0 == index.row()) {
+        qCDebug(app) << "Returning default size 41";
         return QSize(option.rect.width(), 34 + 7);
     } else {
+        qCDebug(app) << "Returning default size 34";
         return QSize(option.rect.width(), 34);
     }
 }
