@@ -1,18 +1,20 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" sourcelanguage="en_US" language="hu">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="hu" sourcelanguage="en_US">
 <context>
     <name>ManualProxy</name>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="322"/>
+        <location filename="../src/view/manual_proxy.cpp" line="363"/>
         <source>Learn Basic Operations</source>
         <translation>Alapvető műveletek megismerése</translation>
     </message>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="324"/>
+        <location filename="../src/view/manual_proxy.cpp" line="366"/>
         <source>Common Application Libraries</source>
         <translation>Közös alkalmazás könyvtárak</translation>
     </message>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="326"/>
+        <location filename="../src/view/manual_proxy.cpp" line="369"/>
         <source>Desktop Environment</source>
         <translation>Asztali Környezet</translation>
     </message>
@@ -20,94 +22,94 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/view/widget/search_completion_window.cpp" line="163"/>
-        <location filename="../src/view/widget/search_completion_window.cpp" line="249"/>
+        <location filename="../src/view/widget/search_completion_window.cpp" line="197"/>
+        <location filename="../src/view/widget/search_completion_window.cpp" line="291"/>
         <source>Search for &quot;%1&quot; in the full text</source>
         <translation>&quot;% 1&quot; kifejezés keresése a teljes szövegben</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="301"/>
+        <location filename="../src/view/web_window.cpp" line="363"/>
         <source>The content was updated</source>
         <translation>A tartalom frissítve</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="624"/>
+        <location filename="../src/view/web_window.cpp" line="767"/>
         <source>Search</source>
         <translation>Keresés</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="627"/>
-        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
+        <location filename="../src/view/web_window.cpp" line="771"/>
         <source>Support</source>
         <translation>Támogatás</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="836"/>
+        <location filename="../src/view/web_window.cpp" line="1038"/>
         <source>Copy</source>
         <translation>Másolás</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="21"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
         <source>Quick Start</source>
         <translation>Gyors Kezdés</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="22"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
         <source>Video Guide</source>
         <translation>Videó útmutató</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="23"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
         <source>System</source>
         <translation>Rendszer</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="24"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
         <source>Applications</source>
         <translation>Alkalmazások</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
         <source>No search results</source>
         <translation>Nincs keresési eredmény</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
         <source>Home</source>
         <translation>Főoldal</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
         <source>  result</source>
         <translation>eredmény</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
         <source>  results</source>
         <translation>eredmények</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="33"/>
         <source>Click to view </source>
         <translation>Kattintson a megtekintéshez</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
         <source>View all</source>
         <translation>Összes megtekintése</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="36"/>
         <source>App Store</source>
         <translation>Áruház</translation>
     </message>
     <message>
-        <location filename="../src/app/dman.cpp" line="105"/>
+        <location filename="../src/app/dman.cpp" line="136"/>
         <source>Manual</source>
         <translation>Kézikönyv</translation>
     </message>
     <message>
-        <location filename="../src/app/dman.cpp" line="106"/>
+        <location filename="../src/app/dman.cpp" line="137"/>
         <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
         <translation>A Kézikönyv célja, hogy segítse a felhasználókat az operációs rendszer és alkalmazásainak megismerésében, konkrét utasításokat és funkcióleírásokat biztosítva.</translation>
     </message>
@@ -115,14 +117,14 @@
 <context>
     <name>WebWindow</name>
     <message>
-        <location filename="../src/view/web_window.cpp" line="765"/>
+        <location filename="../src/view/web_window.cpp" line="952"/>
         <source>Ctrl+Alt+F</source>
         <translation>Ctrl+Alt+F</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="780"/>
+        <location filename="../src/view/web_window.cpp" line="969"/>
         <source>Ctrl+F</source>
         <translation>Ctrl+F</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
